(function () {

/* Imports */
var Meteor = Package.meteor.Meteor;
var global = Package.meteor.global;
var meteorEnv = Package.meteor.meteorEnv;
var ECMAScript = Package.ecmascript.ECMAScript;
var SandstormDb = Package['sandstorm-db'].SandstormDb;
var meteorInstall = Package.modules.meteorInstall;
var Buffer = Package.modules.Buffer;
var process = Package.modules.process;
var Symbol = Package['ecmascript-runtime'].Symbol;
var Map = Package['ecmascript-runtime'].Map;
var Set = Package['ecmascript-runtime'].Set;
var meteorBabelHelpers = Package['babel-runtime'].meteorBabelHelpers;
var Promise = Package.promise.Promise;

/* Package-scope variables */
var ContactProfiles;

var require = meteorInstall({"node_modules":{"meteor":{"sandstorm-contacts":{"contacts-server.js":function(){

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                                                   //
// packages/sandstorm-contacts/contacts-server.js                                                                    //
//                                                                                                                   //
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
                                                                                                                     //
// Sandstorm - Personal Cloud Sandbox                                                                                //
// Copyright (c) 2016 Sandstorm Development Group, Inc. and contributors                                             //
// All rights reserved.                                                                                              //
//                                                                                                                   //
// Licensed under the Apache License, Version 2.0 (the "License");                                                   //
// you may not use this file except in compliance with the License.                                                  //
// You may obtain a copy of the License at                                                                           //
//                                                                                                                   //
//   http://www.apache.org/licenses/LICENSE-2.0                                                                      //
//                                                                                                                   //
// Unless required by applicable law or agreed to in writing, software                                               //
// distributed under the License is distributed on an "AS IS" BASIS,                                                 //
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.                                          //
// See the License for the specific language governing permissions and                                               //
// limitations under the License.                                                                                    //
                                                                                                                     //
Meteor.publish("contactProfiles", function (showAll) {                                                               // 17
  var db = this.connection.sandstormDb;                                                                              // 18
  var _this = this;                                                                                                  // 19
  var userId = this.userId;                                                                                          // 20
                                                                                                                     //
  // We maintain a map from identity IDs to live query handles that track profile changes.                           //
  var contactIdentities = {};                                                                                        // 23
  var disallowGuests = db.getOrganizationDisallowGuests();                                                           // 24
                                                                                                                     //
  function addIdentityOfContact(identityId) {                                                                        // 26
    if (!(identityId in contactIdentities)) {                                                                        // 27
      var user = Meteor.users.findOne({ _id: identityId });                                                          // 28
                                                                                                                     //
      if (disallowGuests && !showAll) {                                                                              // 30
        if (!db.isIdentityInOrganization(user)) {                                                                    // 31
          return;                                                                                                    // 32
        }                                                                                                            // 33
      }                                                                                                              // 34
                                                                                                                     //
      if (user) {                                                                                                    // 36
        SandstormDb.fillInProfileDefaults(user);                                                                     // 37
        SandstormDb.fillInIntrinsicName(user);                                                                       // 38
        var filteredUser = _.pick(user, "_id", "profile");                                                           // 39
        _this.added("contactProfiles", user._id, filteredUser);                                                      // 40
      }                                                                                                              // 41
                                                                                                                     //
      contactIdentities[identityId] = Meteor.users.find({ _id: identityId }, { fields: { profile: 1 } }).observeChanges({
        changed: function changed(id, fields) {                                                                      // 45
          _this.changed("contactProfiles", id, fields);                                                              // 46
        }                                                                                                            // 47
      });                                                                                                            // 44
    }                                                                                                                // 49
  }                                                                                                                  // 50
                                                                                                                     //
  var cursor = db.collections.contacts.find({ ownerId: userId });                                                    // 52
                                                                                                                     //
  var handle = cursor.observe({                                                                                      // 54
    added: function added(contact) {                                                                                 // 55
      addIdentityOfContact(contact.identityId);                                                                      // 56
    },                                                                                                               // 57
                                                                                                                     //
    changed: function changed(contact) {                                                                             // 59
      addIdentityOfContact(contact.identityId);                                                                      // 60
    },                                                                                                               // 61
                                                                                                                     //
    removed: function removed(contact) {                                                                             // 63
      _this.removed("contactProfiles", contact.identityId);                                                          // 64
      var contactIdentity = contactIdentities[contact.identityId];                                                   // 65
      if (contactIdentity) contactIdentities[contact.identityId].stop();                                             // 66
      delete contactIdentities[contact.identityId];                                                                  // 67
    }                                                                                                                // 68
  });                                                                                                                // 54
                                                                                                                     //
  var orgHandle = void 0;                                                                                            // 71
                                                                                                                     //
  if (db.getOrganizationShareContacts() && db.isUserInOrganization(db.collections.users.findOne({ _id: userId }))) {
    var orgCursor = db.collections.users.find({ profile: { $exists: 1 } });                                          // 75
    // TODO(perf): make a mongo query that can find all identities in an organization and add                        //
    // indices for it. Currently, we do some case insensitive matching which mongo can't                             //
    // handle well.                                                                                                  //
                                                                                                                     //
    orgHandle = orgCursor.observe({                                                                                  // 80
      added: function added(user) {                                                                                  // 81
        if (db.isIdentityInOrganization(user) && !db.userHasIdentity(userId, user._id)) {                            // 82
          addIdentityOfContact(user._id);                                                                            // 83
        }                                                                                                            // 84
      },                                                                                                             // 85
                                                                                                                     //
      changed: function changed(user) {                                                                              // 87
        if (db.isIdentityInOrganization(user) && !db.userHasIdentity(userId, user._id)) {                            // 88
          addIdentityOfContact(user._id);                                                                            // 89
        }                                                                                                            // 90
      },                                                                                                             // 91
                                                                                                                     //
      removed: function removed(user) {                                                                              // 93
        if (db.isIdentityInOrganization(user) && !db.userHasIdentity(userId, user._id)) {                            // 94
          _this.removed("contactProfiles", user._id);                                                                // 95
          var contactIdentity = contactIdentities[contact.identityId];                                               // 96
          if (contactIdentity) contactIdentities[contact.identityId].stop();                                         // 97
          delete contactIdentities[user._id];                                                                        // 98
        }                                                                                                            // 99
      }                                                                                                              // 100
    });                                                                                                              // 80
  }                                                                                                                  // 102
                                                                                                                     //
  this.ready();                                                                                                      // 104
                                                                                                                     //
  this.onStop(function () {                                                                                          // 106
    handle.stop();                                                                                                   // 107
    if (orgHandle) {                                                                                                 // 108
      orgHandle.stop();                                                                                              // 109
    }                                                                                                                // 110
                                                                                                                     //
    Object.keys(contactIdentities).forEach(function (identityId) {                                                   // 112
      contactIdentities[identityId].stop();                                                                          // 113
      delete contactIdentities[identityId];                                                                          // 114
    });                                                                                                              // 115
  });                                                                                                                // 116
});                                                                                                                  // 117
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

}}}}},{"extensions":[".js",".json"]});
require("./node_modules/meteor/sandstorm-contacts/contacts-server.js");

/* Exports */
if (typeof Package === 'undefined') Package = {};
(function (pkg, symbols) {
  for (var s in symbols)
    (s in pkg) || (pkg[s] = symbols[s]);
})(Package['sandstorm-contacts'] = {}, {
  ContactProfiles: ContactProfiles
});

})();

//# sourceMappingURL=sandstorm-contacts.js.map
